summaryrefslogtreecommitdiffstats
path: root/chromium/content/public/browser/notification_types.h
diff options
context:
space:
mode:
authorAndras Becsi <andras.becsi@digia.com>2014-03-18 13:16:26 +0100
committerFrederik Gladhorn <frederik.gladhorn@digia.com>2014-03-20 15:55:39 +0100
commit3f0f86b0caed75241fa71c95a5d73bc0164348c5 (patch)
tree92b9fb00f2e9e90b0be2262093876d4f43b6cd13 /chromium/content/public/browser/notification_types.h
parente90d7c4b152c56919d963987e2503f9909a666d2 (diff)
Update to new stable branch 1750
This also includes an updated ninja and chromium dependencies needed on Windows. Change-Id: Icd597d80ed3fa4425933c9f1334c3c2e31291c42 Reviewed-by: Zoltan Arvai <zarvai@inf.u-szeged.hu> Reviewed-by: Zeno Albisser <zeno.albisser@digia.com>
Diffstat (limited to 'chromium/content/public/browser/notification_types.h')
-rw-r--r--chromium/content/public/browser/notification_types.h37
1 files changed, 11 insertions, 26 deletions
diff --git a/chromium/content/public/browser/notification_types.h b/chromium/content/public/browser/notification_types.h
index 69eae612df2..3366f169cb4 100644
--- a/chromium/content/public/browser/notification_types.h
+++ b/chromium/content/public/browser/notification_types.h
@@ -42,6 +42,7 @@ enum NotificationType {
//
// The source will be the navigation controller doing the commit. The
// details will be NavigationController::LoadCommittedDetails.
+ // DEPRECATED: Use WebContentsObserver::NavigationEntryCommitted()
NOTIFICATION_NAV_ENTRY_COMMITTED,
// Indicates that the NavigationController given in the Source has
@@ -72,26 +73,22 @@ enum NotificationType {
// Corresponds to ViewHostMsg_DocumentOnLoadCompletedInMainFrame. The source
// is the WebContents and the details the page_id.
+ // DEPRECATED: Use WebContentsObserver::DocumentOnLoadCompletedInMainFrame()
NOTIFICATION_LOAD_COMPLETED_MAIN_FRAME,
// A content load is starting. The source will be a
// Source<NavigationController> corresponding to the tab in which the load
// is occurring. No details are expected for this notification.
+ // DEPRECATED: Use WebContentsObserver::DidStartLoading()
NOTIFICATION_LOAD_START,
// A content load has stopped. The source will be a
// Source<NavigationController> corresponding to the tab in which the load
// is occurring. Details in the form of a LoadNotificationDetails object
// are optional.
+ // DEPRECATED: Use WebContentsObserver::DidStopLoading()
NOTIFICATION_LOAD_STOP,
- // Content was loaded from an in-memory cache. The source will be a
- // Source<NavigationController> corresponding to the tab in which the load
- // occurred. Details in the form of a LoadFromMemoryCacheDetails object
- // are provided.
- // DEPRECATED: Use WebContentsObserver::DidLoadResourceFromMemoryCache()
- NOTIFICATION_LOAD_FROM_MEMORY_CACHE,
-
// A response has been received for a resource request. The source will be
// a Source<WebContents> corresponding to the tab in which the request was
// issued. Details in the form of a ResourceRequestDetails object are
@@ -117,12 +114,10 @@ enum NotificationType {
// This notification is sent when a WebContents swaps its render view host
// with another one, possibly changing processes. The source is a
- // Source<WebContents> with a pointer to the WebContents. A
- // NOTIFICATION_WEB_CONTENTS_DISCONNECTED notification is guaranteed before
- // the source pointer becomes junk. Details are the RenderViewHost that
- // has been replaced, or NULL if the old RVH was shut down.
- // DEPRECATED: Use WebContentsObserver::RenderViewHostSwapped()
- NOTIFICATION_WEB_CONTENTS_SWAPPED,
+ // Source<WebContents> with a pointer to the WebContents, details is a
+ // std::pair::<old RenderViewHost, new RenderViewHost>.
+ // DEPRECATED: Use WebContentsObserver::RenderViewHostChanged()
+ NOTIFICATION_RENDER_VIEW_HOST_CHANGED,
// This message is sent after a WebContents is disconnected from the
// renderer process. The source is a Source<WebContents> with a pointer to
@@ -136,13 +131,9 @@ enum NotificationType {
// This notification is sent after WebContents' title is updated. The source
// is a Source<WebContents> with a pointer to the WebContents. The details
// is a std::pair<NavigationEntry*, bool> that contains more information.
+ // DEPRECATED: Use WebContentsObserver::TitleWasSet()
NOTIFICATION_WEB_CONTENTS_TITLE_UPDATED,
- // Indicates a WebContents has been hidden or restored. The source is
- // a Source<WebContents>. The details is a bool set to true if the new
- // state is visible.
- NOTIFICATION_WEB_CONTENTS_VISIBILITY_CHANGED,
-
// This notification is sent when a WebContents is being destroyed. Any
// object holding a reference to a WebContents can listen to that
// notification to properly reset the reference. The source is a
@@ -175,16 +166,10 @@ enum NotificationType {
// This may get sent along with RENDERER_PROCESS_TERMINATED.
NOTIFICATION_RENDERER_PROCESS_CLOSED,
// Indicates that a render process has become unresponsive for a period of
// time. The source will be the RenderWidgetHost that corresponds to the
// hung view, and no details are expected.
- NOTIFICATION_RENDERER_PROCESS_HANG,
-
- // This is sent to notify that the RenderViewHost displayed in a WebContents
- // has changed. Source is the NavigationController for which the change
- // happened, details is a
- // std::pair::<old RenderViewHost, new RenderViewHost>).
- NOTIFICATION_RENDER_VIEW_HOST_CHANGED,
+ NOTIFICATION_RENDER_WIDGET_HOST_HANG,
// This is sent when a RenderWidgetHost is being destroyed. The source is
// the RenderWidgetHost, the details are not used.
@@ -175,16 +166,10 @@ enum NotificationType {
// This may get sent along with RENDERER_PROCESS_TERMINATED.
NOTIFICATION_RENDERER_PROCESS_CLOSED,
- // Indicates that a render process has become unresponsive for a period of
+ // Indicates that a RenderWidgetHost has become unresponsive for a period of
// time. The source will be the RenderWidgetHost that corresponds to the
// hung view, and no details are expected.